package com.chelvc.cloud.admin.controller;

import com.chelvc.cloud.admin.copier.UserCopier;
import com.chelvc.cloud.admin.vo.PersonalVO;
import com.chelvc.cloud.uc.api.dto.UserDTO;
import com.chelvc.cloud.uc.api.param.UserPagingParam;
import com.chelvc.cloud.uc.api.service.UserService;
import com.chelvc.cloud.vehicle.api.dto.HelpCategoryDTO;
import com.chelvc.cloud.vehicle.api.param.HelpCategoryPagingParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * 用户接口
 *
 * @author Woody
 * @date 2023/4/30
 */
@Validated
@RestController
@ResponseWrapping
public class UserController {
    @DubboReference
    private UserService userService;

    /**
     * 获取个人信息
     *
     * @return 用户信息
     */
    @GetMapping("/user/mine")
    public PersonalVO getPersonal() {
        return UserCopier.INSTANCE.copying(this.userService.getPersonal());
    }



    /**
     * 查询用户分页
     *
     * @param param 查询参数
     * @return 用户分页信息
     */
    @GetMapping("/user/paging")
    public Pagination<UserDTO> getUserPaging(@Valid UserPagingParam param) {
        return this.userService.getUserPaging(param);
    }
}
